@@ -30,12 +30,10 @@
 #include <KDesktopFile>
 #include <KFileItemDelegate>
 #include <KFilePlacesModel>
-#include <KGlobalSettings>
 #include <KLocale>
 #include <KIconEffect>
 #include <KIO/NetAccess>
 #include <KIO/PreviewJob>
-#include <KMenu>
 #include <KNewFileMenu>
 #include <konqmimedata.h>
 #include <konq_operations.h>
@@ -49,14 +47,9 @@
 #include "dolphinmainwindow.h"
 #include "filterbar/filterbar.h"
 #include "search/dolphinsearchbox.h"
-#include "settings/dolphinsettings.h"
 #include "statusbar/dolphinstatusbar.h"
-#include "views/dolphincolumnview.h"
-#include "views/dolphindetailsview.h"
+#include "views/dolphinplacesmodel.h"
 #include "views/draganddrophelper.h"
-#include "views/dolphiniconsview.h"
-#include "views/dolphinmodel.h"
-#include "views/dolphinviewcontroller.h"
 #include "views/viewmodecontroller.h"
 #include "views/viewproperties.h"
 
@@ -77,15 +70,15 @@ DolphinViewContainer::DolphinViewContainer(const KUrl& url, QWidget* parent) :
     m_topLayout->setSpacing(0);
     m_topLayout->setMargin(0);
 
-    m_urlNavigator = new KUrlNavigator(DolphinSettings::instance().placesModel(), url, this);
-    connect(m_urlNavigator, SIGNAL(urlsDropped(const KUrl&, QDropEvent*)),
-            this, SLOT(dropUrls(const KUrl&, QDropEvent*)));
+    m_urlNavigator = new KUrlNavigator(DolphinPlacesModel::instance(), url, this);
+    connect(m_urlNavigator, SIGNAL(urlsDropped(KUrl,QDropEvent*)),
+            this, SLOT(dropUrls(KUrl,QDropEvent*)));
     connect(m_urlNavigator, SIGNAL(activated()),
             this, SLOT(activate()));
     connect(m_urlNavigator->editor(), SIGNAL(completionModeChanged(KGlobalSettings::Completion)),
             this, SLOT(saveUrlCompletionMode(KGlobalSettings::Completion)));
 
-    const GeneralSettings* settings = DolphinSettings::instance().generalSettings();
+    const GeneralSettings* settings = GeneralSettings::self();
     m_urlNavigator->setUrlEditable(settings->editableUrl());
     m_urlNavigator->setShowFullPath(settings->showFullPath());
     m_urlNavigator->setHomeUrl(KUrl(settings->homeUrl()));
@@ -99,27 +92,28 @@ DolphinViewContainer::DolphinViewContainer(const KUrl& url, QWidget* parent) :
     connect(m_searchBox, SIGNAL(returnPressed(QString)), this, SLOT(requestFocus()));
 
     m_view = new DolphinView(url, this);
-    connect(m_view, SIGNAL(urlChanged(const KUrl&)),      m_urlNavigator, SLOT(setUrl(const KUrl&)));
+    connect(m_view, SIGNAL(urlChanged(KUrl)),             m_urlNavigator, SLOT(setUrl(KUrl)));
     connect(m_view, SIGNAL(writeStateChanged(bool)),      this, SIGNAL(writeStateChanged(bool)));
     connect(m_view, SIGNAL(requestItemInfo(KFileItem)),   this, SLOT(showItemInfo(KFileItem)));
-    connect(m_view, SIGNAL(errorMessage(const QString&)), this, SLOT(showErrorMessage(const QString&)));
-    connect(m_view, SIGNAL(infoMessage(const QString&)),  this, SLOT(showInfoMessage(const QString&)));
-    connect(m_view, SIGNAL(itemTriggered(KFileItem)),     this, SLOT(slotItemTriggered(KFileItem)));
-    connect(m_view, SIGNAL(redirection(KUrl, KUrl)),      this, SLOT(redirect(KUrl, KUrl)));
+    connect(m_view, SIGNAL(errorMessage(QString)),        this, SLOT(showErrorMessage(QString)));
+    connect(m_view, SIGNAL(infoMessage(QString)),         this, SLOT(showInfoMessage(QString)));
+    connect(m_view, SIGNAL(itemActivated(KFileItem)),     this, SLOT(slotItemActivated(KFileItem)));
+    connect(m_view, SIGNAL(redirection(KUrl,KUrl)),       this, SLOT(redirect(KUrl,KUrl)));
     connect(m_view, SIGNAL(startedPathLoading(KUrl)),     this, SLOT(slotStartedPathLoading()));
     connect(m_view, SIGNAL(finishedPathLoading(KUrl)),    this, SLOT(slotFinishedPathLoading()));
     connect(m_view, SIGNAL(itemCountChanged()),           this, SLOT(delayedStatusBarUpdate()));
     connect(m_view, SIGNAL(pathLoadingProgress(int)),     this, SLOT(updateProgress(int)));
-    connect(m_view, SIGNAL(infoMessage(const QString&)),  this, SLOT(showInfoMessage(const QString&)));
-    connect(m_view, SIGNAL(errorMessage(const QString&)), this, SLOT(showErrorMessage(const QString&)));
-    connect(m_view, SIGNAL(urlIsFileError(const KUrl&)),  this, SLOT(openFile(const KUrl&)));
-    connect(m_view, SIGNAL(selectionChanged(const KFileItemList&)),    this, SLOT(delayedStatusBarUpdate()));
-    connect(m_view, SIGNAL(operationCompletedMessage(const QString&)), this, SLOT(showOperationCompletedMessage(const QString&)));
+    connect(m_view, SIGNAL(infoMessage(QString)),         this, SLOT(showInfoMessage(QString)));
+    connect(m_view, SIGNAL(errorMessage(QString)),        this, SLOT(showErrorMessage(QString)));
+    connect(m_view, SIGNAL(urlIsFileError(KUrl)),         this, SLOT(openFile(KUrl)));
+    connect(m_view, SIGNAL(selectionChanged(KFileItemList)),    this, SLOT(delayedStatusBarUpdate()));
+    connect(m_view, SIGNAL(operationCompletedMessage(QString)), this, SLOT(showOperationCompletedMessage(QString)));
+    connect(m_view, SIGNAL(urlAboutToBeChanged(KUrl)),          this, SLOT(slotViewUrlAboutToBeChanged(KUrl)));
 
-    connect(m_urlNavigator, SIGNAL(urlChanged(const KUrl&)),
-            this, SLOT(slotUrlNavigatorLocationChanged(const KUrl&)));
-    connect(m_urlNavigator, SIGNAL(urlAboutToBeChanged(const KUrl&)),
-            this, SLOT(saveViewState()));
+    connect(m_urlNavigator, SIGNAL(urlAboutToBeChanged(KUrl)),
+            this, SLOT(slotUrlNavigatorLocationAboutToBeChanged(KUrl)));
+    connect(m_urlNavigator, SIGNAL(urlChanged(KUrl)),
+            this, SLOT(slotUrlNavigatorLocationChanged(KUrl)));
     connect(m_urlNavigator, SIGNAL(historyChanged()),
             this, SLOT(slotHistoryChanged()));
 
@@ -140,11 +134,11 @@ DolphinViewContainer::DolphinViewContainer(const KUrl& url, QWidget* parent) :
     // initialize filter bar
     m_filterBar = new FilterBar(this);
     m_filterBar->setVisible(settings->filterBar());
-    connect(m_filterBar, SIGNAL(filterChanged(const QString&)),
-            this, SLOT(setNameFilter(const QString&)));
+    connect(m_filterBar, SIGNAL(filterChanged(QString)),
+            this, SLOT(setNameFilter(QString)));
     connect(m_filterBar, SIGNAL(closeRequest()),
             this, SLOT(closeFilterBar()));
-    connect(m_view, SIGNAL(urlChanged(const KUrl&)),
+    connect(m_view, SIGNAL(urlChanged(KUrl)),
             m_filterBar, SLOT(clear()));
 
     m_topLayout->addWidget(m_urlNavigator);
@@ -219,14 +213,13 @@ DolphinSearchBox* DolphinViewContainer::searchBox()
 
 void DolphinViewContainer::refresh()
 {
-    GeneralSettings* settings = DolphinSettings::instance().generalSettings();
-    if (settings->modifiedStartupSettings()) {
+    if (GeneralSettings::modifiedStartupSettings()) {
         // The startup settings should only get applied if they have been
         // modified by the user. Otherwise keep the (possibly) different current
         // settings of the URL navigator and the filterbar.
-        m_urlNavigator->setUrlEditable(settings->editableUrl());
-        m_urlNavigator->setShowFullPath(settings->showFullPath());
-        setFilterBarVisible(settings->filterBar());
+        m_urlNavigator->setUrlEditable(GeneralSettings::editableUrl());
+        m_urlNavigator->setShowFullPath(GeneralSettings::showFullPath());
+        setFilterBarVisible(GeneralSettings::filterBar());
     }
 
     m_view->refresh();
@@ -378,6 +371,53 @@ void DolphinViewContainer::slotFinishedPathLoading()
     }
 }
 
+void DolphinViewContainer::slotItemActivated(const KFileItem& item)
+{
+    // It is possible to activate items on inactive views by
+    // drag & drop operations. Assure that activating an item always
+    // results in an active view.
+    m_view->setActive(true);
+
+    KUrl url = item.targetUrl();
+
+    if (item.isDir()) {
+        m_view->setUrl(url);
+        return;
+    }
+
+    if (GeneralSettings::browseThroughArchives() && item.isFile() && url.isLocalFile()) {
+        // Generic mechanism for redirecting to tar:/<path>/ when clicking on a tar file,
+        // zip:/<path>/ when clicking on a zip file, etc.
+        // The .protocol file specifies the mimetype that the kioslave handles.
+        // Note that we don't use mimetype inheritance since we don't want to
+        // open OpenDocument files as zip folders...
+        const QString protocol = KProtocolManager::protocolForArchiveMimetype(item.mimetype());
+        if (!protocol.isEmpty()) {
+            url.setProtocol(protocol);
+            m_view->setUrl(url);
+            return;
+        }
+    }
+
+    if (item.mimetype() == QLatin1String("application/x-desktop")) {
+        // Redirect to the URL in Type=Link desktop files
+        KDesktopFile desktopFile(url.toLocalFile());
+        if (desktopFile.hasLinkType()) {
+            url = desktopFile.readUrl();
+            m_view->setUrl(url);
+            return;
+        }
+    }
+
+    item.run();
+}
+
+void DolphinViewContainer::openFile(const KUrl& url)
+{
+    const KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url);
+    slotItemActivated(item);
+}
+
 void DolphinViewContainer::showItemInfo(const KFileItem& item)
 {
     if (item.isNull()) {
@@ -389,7 +429,13 @@ void DolphinViewContainer::showItemInfo(const KFileItem& item)
             m_statusBar->clear();
         }
     } else {
-        m_statusBar->setMessage(item.getStatusBarInfo(), DolphinStatusBar::Default);
+        QString message;
+        if (item.isDir()) {
+            message = item.text();
+        } else {
+            message = i18nc("@info:status filename (type)", "%1 (%2)", item.text(), item.mimeComment());
+        }
+        m_statusBar->setMessage(message, DolphinStatusBar::Default);
     }
 }
 
@@ -427,20 +473,36 @@ void DolphinViewContainer::activate()
     setActive(true);
 }
 
-void DolphinViewContainer::saveViewState()
+void DolphinViewContainer::slotViewUrlAboutToBeChanged(const KUrl& url)
 {
-    QByteArray locationState;
-    QDataStream stream(&locationState, QIODevice::WriteOnly);
-    m_view->saveState(stream);
-    m_urlNavigator->saveLocationState(locationState);
+    // URL changes of the view can happen in two ways:
+    // 1. The URL navigator gets changed and will trigger the view to update its URL
+    // 2. The URL of the view gets changed and will trigger the URL navigator to update
+    //    its URL (e.g. by clicking on an item)
+    // In this scope the view-state may only get saved in case 2:
+    if (url != m_urlNavigator->locationUrl()) {
+        saveViewState();
+    }
+}
+
+void DolphinViewContainer::slotUrlNavigatorLocationAboutToBeChanged(const KUrl& url)
+{
+    // URL changes of the view can happen in two ways:
+    // 1. The URL navigator gets changed and will trigger the view to update its URL
+    // 2. The URL of the view gets changed and will trigger the URL navigator to update
+    //    its URL (e.g. by clicking on an item)
+    // In this scope the view-state may only get saved in case 1:
+    if (url != m_view->url()) {
+        saveViewState();
+    }
 }
 
 void DolphinViewContainer::slotUrlNavigatorLocationChanged(const KUrl& url)
 {
     if (KProtocolManager::supportsListing(url)) {
         setSearchModeEnabled(isSearchUrl(url));
-
         m_view->setUrl(url);
+
         if (isActive() && !isSearchUrl(url)) {
             // When an URL has been entered, the view should get the focus.
             // The focus must be requested asynchronously, as changing the URL might create
@@ -476,7 +538,8 @@ void DolphinViewContainer::slotUrlNavigatorLocationChanged(const KUrl& url)
 
 void DolphinViewContainer::dropUrls(const KUrl& destination, QDropEvent* event)
 {
-    DragAndDropHelper::instance().dropUrls(KFileItem(), destination, event, this);
+    const KFileItem destItem(KFileItem::Unknown, KFileItem::Unknown, destination);
+    DragAndDropHelper::dropUrls(destItem, event);
 }
 
 void DolphinViewContainer::redirect(const KUrl& oldUrl, const KUrl& newUrl)
@@ -502,15 +565,12 @@ void DolphinViewContainer::requestFocus()
 
 void DolphinViewContainer::saveUrlCompletionMode(KGlobalSettings::Completion completion)
 {
-    DolphinSettings& settings = DolphinSettings::instance();
-    settings.generalSettings()->setUrlCompletionMode(completion);
-    settings.save();
+    GeneralSettings::setUrlCompletionMode(completion);
 }
 
 void DolphinViewContainer::slotHistoryChanged()
 {
     QByteArray locationState = m_urlNavigator->locationState();
-
     if (!locationState.isEmpty()) {
         QDataStream stream(&locationState, QIODevice::ReadOnly);
         m_view->restoreState(stream);
@@ -543,48 +603,12 @@ bool DolphinViewContainer::isSearchUrl(const KUrl& url) const
     return protocol.contains("search") || (protocol == QLatin1String("nepomuk"));
 }
 
-void DolphinViewContainer::slotItemTriggered(const KFileItem& item)
+void DolphinViewContainer::saveViewState()
 {
-    KUrl url = item.targetUrl();
-
-    if (item.isDir()) {
-        m_view->setUrl(url);
-        return;
-    }
-
-    const GeneralSettings* settings = DolphinSettings::instance().generalSettings();
-    const bool browseThroughArchives = settings->browseThroughArchives();
-    if (browseThroughArchives && item.isFile() && url.isLocalFile()) {
-        // Generic mechanism for redirecting to tar:/<path>/ when clicking on a tar file,
-        // zip:/<path>/ when clicking on a zip file, etc.
-        // The .protocol file specifies the mimetype that the kioslave handles.
-        // Note that we don't use mimetype inheritance since we don't want to
-        // open OpenDocument files as zip folders...
-        const QString protocol = KProtocolManager::protocolForArchiveMimetype(item.mimetype());
-        if (!protocol.isEmpty()) {
-            url.setProtocol(protocol);
-            m_view->setUrl(url);
-            return;
-        }
-    }
-
-    if (item.mimetype() == "application/x-desktop") {
-        // redirect to the url in Type=Link desktop files
-        KDesktopFile desktopFile(url.toLocalFile());
-        if (desktopFile.hasLinkType()) {
-            url = desktopFile.readUrl();
-            m_view->setUrl(url);
-            return;
-        }
-    }
-
-    item.run();
-}
-
-void DolphinViewContainer::openFile(const KUrl& url)
-{
-    const KFileItem item(KFileItem::Unknown, KFileItem::Unknown, url);
-    slotItemTriggered(item);
+    QByteArray locationState;
+    QDataStream stream(&locationState, QIODevice::WriteOnly);
+    m_view->saveState(stream);
+    m_urlNavigator->saveLocationState(locationState);
 }
 
 #include "dolphinviewcontainer.moc"
