@@ -39,6 +39,7 @@
 #include <kfileplacesmodel.h>
 #include <kfilepreviewgenerator.h>
 #include <KGlobalSettings>
+#include <KProtocolInfo>
 #include <KStandardShortcut>
 #include <KStringHandler>
 #include <KTemporaryFile>
@@ -71,8 +72,8 @@
 #include <Plasma/ToolTipManager>
 #include <Plasma/Wallpaper>
 #include <Plasma/WindowEffects>
+#include <Plasma/Applet>
 
-#include "dirlister.h"
 #include "dialog.h"
 #include "folderviewadapter.h"
 #include "iconwidget.h"
@@ -355,6 +356,7 @@ void FolderView::init()
     m_textColor           = cg.readEntry("textColor", QColor(Qt::transparent));
     m_iconsLocked         = cg.readEntry("iconsLocked", false);
     m_alignToGrid         = cg.readEntry("alignToGrid", false);
+    m_clickToView         = cg.readEntry("clickForFolderPreviews", true);
     m_previewPlugins      = cg.readEntry("previewPlugins", QStringList() << "imagethumbnail" << "jpegthumbnail");
     m_sortDirsFirst       = cg.readEntry("sortDirsFirst", true);
     m_sortColumn          = cg.readEntry("sortColumn", int(KDirModel::Name));
@@ -377,15 +379,18 @@ void FolderView::init()
     m_model->setDynamicSortFilter(m_sortColumn != -1);
     m_model->sort(m_sortColumn != -1 ? m_sortColumn : KDirModel::Name, Qt::AscendingOrder);
 
-    DirLister *lister = new DirLister(this);
-    lister->setDelayedMimeTypes(true);
-    lister->setAutoErrorHandlingEnabled(false, 0);
+    m_dirLister = new DirLister(this);
+    m_dirLister->setDelayedMimeTypes(true);
+    m_dirLister->setAutoErrorHandlingEnabled(false, 0);
 
-    m_dirModel->setDirLister(lister);
+    m_dirModel->setDirLister(m_dirLister);
 
-    if (!m_url.isValid()) {
-
-        //FIXME: 4.3 Need to update folderview's description
+    if (m_url.isValid()) {
+        // this means that we were passed a URL via the args list in the constructor
+        // setUrl has already been called, we just need to save it in the config file
+        KConfigGroup cg = config();
+        cg.writeEntry("url", m_url);
+    } else {
         QString path = QDir::homePath();
         if (isContainment()) {
             const QString desktopPath = KGlobalSettings::desktopPath();
@@ -396,19 +401,10 @@ void FolderView::init()
             }
         }
         setUrl(cg.readEntry("url", KUrl(path)));
-
-    } else {
-        KConfigGroup cg = config();
-        cg.writeEntry("url", m_url);
     }
 
-    // TODO: 4.3 Check if the URL is a remote URL, and if it is check the network status
-    //       and display a message saying it's not available, instead of trying to open
-    //       the URL and waiting for the job to time out.
-    lister->openUrl(m_url);
-
     createActions();
-    
+
     if (isContainment()) {
         setupIconView();
 
@@ -429,7 +425,17 @@ void FolderView::init()
         }
     }
 
+    /*
+    TODO Mark the cut icons as cut
     connect(QApplication::clipboard(), SIGNAL(dataChanged()), SLOT(clipboardDataChanged()));
+    */
+}
+
+void FolderView::networkAvailable()
+{
+    if (KProtocolInfo::protocolClass(m_url.protocol()) == ":local") {
+        m_dirLister->openUrl(m_url);
+    }
 }
 
 void FolderView::configChanged()
@@ -441,14 +447,16 @@ void FolderView::configChanged()
     bool preserveIconPositions = false;
 
     //Reload m_customLabel values
-    QString label = m_customLabel;
-    m_customLabel = cg.readEntry("customLabel", m_customLabel);
+    const QString label = cg.readEntry("customLabel", m_customLabel);
     if (label != m_customLabel) {
+        m_customLabel = label;
         setAppletTitle();
         needReload = true;
     }
-    bool blank = cg.readEntry("blankLabel", m_blankLabel);
+
+    const bool blank = cg.readEntry("blankLabel", m_blankLabel);
     if (blank != m_blankLabel) {
+        m_blankLabel = blank;
         needReload = true;
     }
     //Reload m_customIconSize values
@@ -460,19 +468,21 @@ void FolderView::configChanged()
 
     m_showPreviews = cg.readEntry("showPreviews", m_showPreviews);
     m_drawShadows  = cg.readEntry("drawShadows", m_drawShadows);
-    m_iconsLocked  = cg.readEntry("iconsLocked", m_iconsLocked);
-    m_alignToGrid  = cg.readEntry("alignToGrid", m_alignToGrid);
+    m_clickToView  = cg.readEntry("clickForFolderPreviews", m_clickToView);
     m_numTextLines = cg.readEntry("numTextLines", m_numTextLines);
-
-    const int filterType = m_filterType;
-    m_filterType   = cg.readEntry("filter", m_filterType);
-    if (filterType != m_filterType) {
-        needReload = true;
+    m_alignToGrid  = cg.readEntry("alignToGrid", m_alignToGrid);
+    if (QAction *action = m_actionCollection.action("auto_align")) {
+        action->setChecked(m_alignToGrid);
     }
 
-    QColor color = m_textColor;
-    m_textColor = cg.readEntry("textColor", m_textColor);
+    m_iconsLocked  = cg.readEntry("iconsLocked", m_iconsLocked);
+    if (QAction *action = m_actionCollection.action("lock_icons")) {
+        action->setChecked(m_iconsLocked);
+    }
+
+    const QColor color = cg.readEntry("textColor", m_textColor);
     if (color != m_textColor) {
+        m_textColor = color;
         needReload = true;
     }
 
@@ -490,9 +500,9 @@ void FolderView::configChanged()
     m_sortDirsFirst = cg.readEntry("sortDirsFirst", m_sortDirsFirst);
     toggleDirectoriesFirst(m_sortDirsFirst);
 
-    const int sortColumn = m_sortColumn;
-    m_sortColumn = cg.readEntry("sortColumn", m_sortColumn);
+    const int sortColumn = cg.readEntry("sortColumn", m_sortColumn);
     if (m_sortColumn != sortColumn) {
+        m_sortColumn = sortColumn;
         if (m_sortColumn != -1) {
             m_model->invalidate();
             m_model->sort(m_sortColumn, Qt::AscendingOrder);
@@ -504,28 +514,35 @@ void FolderView::configChanged()
         updateSortActionsState();
     }
 
-    const QString filterFiles = m_filterFiles;
-    m_filterFiles = cg.readEntry("filterFiles", m_filterFiles);
+    const int filterType = cg.readEntry("filter", m_filterType);
+    if (filterType != m_filterType) {
+        m_filterType = filterType;
+        m_model->setFilterMode(ProxyModel::filterModeFromInt(m_filterType));
+        needReload = true;
+    }
 
+    m_userSelectedShowAllFiles = m_filterType;
+
+    const QString filterFiles = cg.readEntry("filterFiles", m_filterFiles);
     if (filterFiles != m_filterFiles) {
+        m_filterFiles = filterFiles;
+        m_model->setFileNameFilter(m_filterFiles);
         needReload = true;
     }
 
-    const QStringList mimeFilter = m_filterFilesMimeList;
-    m_filterFilesMimeList = cg.readEntry("mimeFilter", m_filterFilesMimeList);
-
+    const QStringList mimeFilter = cg.readEntry("mimeFilter", m_filterFilesMimeList);
     if (mimeFilter != m_filterFilesMimeList) {
+        m_filterFilesMimeList = mimeFilter;
+        m_model->setMimeTypeFilterList(m_filterFilesMimeList);
         needReload = true;
     }
 
-    const KUrl url = m_url;
-    m_url = cg.readEntry("url", m_url);
+    const KUrl url = cg.readEntry("url", m_url);
     if (url != m_url) {
-        setUrl(m_url);
+        m_url = url;
         needReload = true;
     }
 
-
     if (m_iconView) {
         updateIconViewState();
     }
@@ -539,17 +556,17 @@ void FolderView::configChanged()
         QStringList iconPositionsData;
         if (preserveIconPositions && m_iconView) {
             iconPositionsData = m_iconView->iconPositionsData();
-
         }
 
-
         if (preserveIconPositions && m_iconView) {
              m_iconView->setIconPositionsData(iconPositionsData);
         }
+
         // So the KFileItemActions will be recreated for the new URL.
         delete m_itemActions;
         m_itemActions = 0;
-        m_dirModel->dirLister()->openUrl(m_url);
+
+        setUrl(m_url);
     }
 }
 
@@ -671,6 +688,7 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
     uiDisplay.flowCombo->addItem(i18n("Right to Left, Top to Bottom"), IconView::RightToLeft);
 
     uiDisplay.alignToGrid->setChecked(m_alignToGrid);
+    uiDisplay.setClicktoView->setChecked(m_clickToView);
     uiDisplay.lockInPlace->setChecked(m_iconsLocked);
     uiDisplay.drawShadows->setChecked(m_drawShadows);
     uiDisplay.showPreviews->setChecked(m_showPreviews);
@@ -740,6 +758,7 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
     connect(uiDisplay.showPreviews, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiDisplay.lockInPlace, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiDisplay.alignToGrid, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
+    connect(uiDisplay.setClicktoView, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
     connect(uiDisplay.numLinesEdit, SIGNAL(valueChanged(int)), parent, SLOT(settingsModified()));
     connect(uiDisplay.colorButton, SIGNAL(changed(QColor)), parent, SLOT(settingsModified()));
     connect(uiDisplay.drawShadows, SIGNAL(toggled(bool)), parent, SLOT(settingsModified()));
@@ -773,34 +792,12 @@ void FolderView::configAccepted()
         url = KUrl(QDir::homePath());
     }
 
-    // Now, we have to iterate over all items (not only the filtered ones). For that reason we have
-    // to ask the source model, not the proxy model.
-    QStringList selectedItems;
-    ProxyMimeModel *proxyModel = static_cast<ProxyMimeModel*>(uiFilter.filterFilesList->model());
-    for (int i = 0; i < proxyModel->sourceModel()->rowCount(); i++) {
-        const QModelIndex index = proxyModel->sourceModel()->index(i, 0);
-        if (index.model()->data(index, Qt::CheckStateRole).toInt() == Qt::Checked) {
-            KMimeType *mime = static_cast<KMimeType*>(index.internalPointer());
-            if (mime) {
-                selectedItems << mime->name();
-            }
-        }
-    }
-
-    const int filterType = uiFilter.filterType->currentIndex();
     KConfigGroup cg = config();
-    bool needReload = false;
-    bool preserveIconPositions = false;
 
-    if (m_drawShadows != uiDisplay.drawShadows->isChecked()) {
-        m_drawShadows = uiDisplay.drawShadows->isChecked();
-        cg.writeEntry("drawShadows", m_drawShadows);
-    }
+    cg.writeEntry("drawShadows", uiDisplay.drawShadows->isChecked());
 
     if (m_showPreviews != uiDisplay.showPreviews->isChecked()) {
-        m_showPreviews = uiDisplay.showPreviews->isChecked();
-        cg.writeEntry("showPreviews", m_showPreviews);
-
+        cg.writeEntry("showPreviews", uiDisplay.showPreviews->isChecked());
         //As disabling the previews will force a rearrangement, we need to manually
         //save and restore the icons positions
 
@@ -821,124 +818,54 @@ void FolderView::configAccepted()
 
     if (m_previewGenerator && m_previewPlugins != m_previewGenerator->enabledPlugins()) {
         cg.writeEntry("previewPlugins", m_previewPlugins);
-        m_previewGenerator->setEnabledPlugins(m_previewPlugins);
-
-        //Changing the preview plugins will also need a reload to work, so we need to preserve
-        //the icons position
-        needReload = true;
-        preserveIconPositions = true;
     }
-    
-    const QColor defaultColor = isContainment() ? Qt::white :
-            Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
+
+    const QColor defaultColor = isContainment() ? Qt::white
+                                                : Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
     const QColor color = uiDisplay.colorButton->color();
     if ((m_textColor != Qt::transparent && color != m_textColor) ||
         (m_textColor == Qt::transparent && color != defaultColor))
     {
-        m_textColor = color;
-        cg.writeEntry("textColor", m_textColor);
+        cg.writeEntry("textColor", color);
     }
 
-    if (m_numTextLines != uiDisplay.numLinesEdit->value()) {
-        m_numTextLines = uiDisplay.numLinesEdit->value();
-        cg.writeEntry("numTextLines", m_numTextLines);
-    }
+    cg.writeEntry("numTextLines", uiDisplay.numLinesEdit->value());
 
     const QList<int> iconSizes = QList<int>() << 16 << 22 << 32 << 48 << 64 << 128;
     const int size = iconSizes.at(uiDisplay.sizeSlider->value());
-    if (size != iconSize().width())
-    {
-        m_customIconSize = size;
-        cg.writeEntry("customIconSize", m_customIconSize);
-
-        // This is to force the preview images to be regenerated with the new size
-        if (m_showPreviews) {
-            needReload = true;
-        }
-    }
+    cg.writeEntry("customIconSize", size);
 
     const int sortColumn = uiDisplay.sortCombo->itemData(uiDisplay.sortCombo->currentIndex()).toInt();
-    if (m_sortColumn != sortColumn) {
-        m_sortColumn = sortColumn;
-        if (m_sortColumn != -1) {
-            m_model->invalidate();
-            m_model->sort(m_sortColumn, Qt::AscendingOrder);
-            m_model->setDynamicSortFilter(true);
-        } else if (m_iconView) {
-            m_iconView->setCustomLayout(true);
-            m_model->setDynamicSortFilter(false);
-        }
-        updateSortActionsState();
-        cg.writeEntry("sortColumn", m_sortColumn);
-    }
+    cg.writeEntry("sortColumn", sortColumn);
 
     const int flow = uiDisplay.flowCombo->itemData(uiDisplay.flowCombo->currentIndex()).toInt();
-    if (m_flow != flow) {
-        m_flow = static_cast<IconView::Flow>(flow);
-        cg.writeEntry("flow", flow);
-    }
+    cg.writeEntry("flow", flow);
 
-    if (m_alignToGrid != uiDisplay.alignToGrid->isChecked()) {
-        m_alignToGrid = uiDisplay.alignToGrid->isChecked();
-        cg.writeEntry("alignToGrid", m_alignToGrid);
-        m_actionCollection.action("auto_align")->setChecked(m_alignToGrid);
-    }
-
-    if (m_iconsLocked != uiDisplay.lockInPlace->isChecked()) {
-        m_iconsLocked = uiDisplay.lockInPlace->isChecked();
-        cg.writeEntry("iconsLocked", m_iconsLocked);
-        m_actionCollection.action("lock_icons")->setChecked(m_iconsLocked);
-    }
+    cg.writeEntry("alignToGrid", uiDisplay.alignToGrid->isChecked());
+    cg.writeEntry("clickForFolderPreviews", uiDisplay.setClicktoView->isChecked());
+    cg.writeEntry("iconsLocked", uiDisplay.lockInPlace->isChecked());
 
     cg.writeEntry("blankLabel" , m_blankLabel);
     cg.writeEntry("customLabel", m_customLabel);
 
-    if (m_url != url || m_filterFiles != uiFilter.filterFilesPattern->text() ||
-        m_filterFilesMimeList != selectedItems || m_filterType != filterType)
-    {
-        m_model->setFileNameFilter(uiFilter.filterFilesPattern->text());
-        m_filterFiles = uiFilter.filterFilesPattern->text();
-        m_filterFilesMimeList = selectedItems;
-        m_filterType = filterType;
-        setUrl(url);
+    cg.writeEntry("url", url);
+    cg.writeEntry("filterFiles", uiFilter.filterFilesPattern->text());
+    cg.writeEntry("filter", uiFilter.filterType->currentIndex());
 
-        cg.writeEntry("url", m_url);
-        cg.writeEntry("filterFiles", m_filterFiles);
-        cg.writeEntry("filter", m_filterType);
-        m_userSelectedShowAllFiles = m_filterType;
-        cg.writeEntry("mimeFilter", m_filterFilesMimeList);
-
-        m_model->setMimeTypeFilterList(m_filterFilesMimeList);
-        m_model->setFilterMode(ProxyModel::filterModeFromInt(m_filterType));
-        needReload = true;
-    } else {
-        setAppletTitle();
-    }
-
-    if (m_iconView) {
-        updateIconViewState();
-    }
-
-    if (m_listView) {
-        updateListViewState();
-    }
-
-    if (needReload) {
-        //Manually save and restore the icon positions if we need it
-        QStringList iconPositionsData;
-        if (preserveIconPositions && m_iconView) {
-            iconPositionsData = m_iconView->iconPositionsData();
+    // Now, we have to iterate over all items (not only the filtered ones). For that reason we have
+    // to ask the source model, not the proxy model.
+    QStringList selectedItems;
+    ProxyMimeModel *proxyModel = static_cast<ProxyMimeModel*>(uiFilter.filterFilesList->model());
+    for (int i = 0; i < proxyModel->sourceModel()->rowCount(); i++) {
+        const QModelIndex index = proxyModel->sourceModel()->index(i, 0);
+        if (index.model()->data(index, Qt::CheckStateRole).toInt() == Qt::Checked) {
+            KMimeType *mime = static_cast<KMimeType*>(index.internalPointer());
+            if (mime) {
+                selectedItems << mime->name();
+            }
         }
-
-        m_dirModel->dirLister()->openUrl(m_url);
-
-        if (preserveIconPositions && m_iconView) {
-             m_iconView->setIconPositionsData(iconPositionsData);
-        }
-        // So the KFileItemActions will be recreated for the new URL.
-        delete m_itemActions;
-        m_itemActions = 0;
     }
+    cg.writeEntry("mimeFilter", selectedItems);
 
     m_delayedSaveTimer.start(5000, this);
     emit configNeedsSaving();
@@ -1058,7 +985,7 @@ void FolderView::updateIconViewState()
     m_iconView->setWordWrap(m_numTextLines > 1);
     m_iconView->setAlignToGrid(m_alignToGrid);
     m_iconView->setIconsMoveable(!m_iconsLocked);
-    m_iconView->setClickToViewFolders(config().readEntry("clickForFolderPreviews", true));
+    m_iconView->setClickToViewFolders(m_clickToView);
 
     if (m_label) {
         m_label->setPalette(palette);
@@ -1197,28 +1124,17 @@ void FolderView::networkStatusChanged(Solid::Networking::Status status)
     }
 }
 
+/*
+// TODO Mark the cut icons as cut, but test performance!
 void FolderView::clipboardDataChanged()
 {
     const QMimeData *mimeData = QApplication::clipboard()->mimeData();
     if (KonqMimeData::decodeIsCutSelection(mimeData)) {
         KUrl::List urls = KUrl::List::fromMimeData(mimeData);
-
-        // TODO Mark the cut icons as cut
-    }
-
-    // Update the paste action
-    if (QAction *action = m_actionCollection.action("paste"))
-    {
-        const QString actionText = KIO::pasteActionText();
-        if (!actionText.isEmpty()) {
-            action->setText(actionText);
-            action->setEnabled(true);
-        } else {
-            action->setText(i18n("&Paste"));
-            action->setEnabled(false);
-        }
+        .. marking items as cut code would go here ..
     }
 }
+*/
 
 void FolderView::saveIconPositions() const
 {
@@ -1361,21 +1277,26 @@ void FolderView::updateScreenRegion()
 
 void FolderView::dragEnterEvent(QGraphicsSceneDragDropEvent *event)
 {
-    const QString appletMimeType = static_cast<Plasma::Corona*>(scene())->appletMimeType();
-    event->setAccepted(isContainment() && immutability() == Plasma::Mutable &&
-                       event->mimeData()->hasFormat(appletMimeType));
+    if (isContainment()) {
+        Containment::dragEnterEvent(event);
+    }
 }
 
 void FolderView::dragMoveEvent(QGraphicsSceneDragDropEvent *event)
 {
-    const QString appletMimeType = static_cast<Plasma::Corona*>(scene())->appletMimeType();
-    event->setAccepted(isContainment() && event->mimeData()->hasFormat(appletMimeType));
+    if (isContainment()) {
+        QGraphicsItem *item = scene()->itemAt(event->scenePos());
+        if (item == m_iconView) {
+            event->setAccepted(true);
+        } else {
+            Containment::dragMoveEvent(event);
+        }
+    }
 }
 
 void FolderView::dropEvent(QGraphicsSceneDragDropEvent *event)
 {
-    const QString appletMimeType = static_cast<Plasma::Corona*>(scene())->appletMimeType();
-    if (isContainment() && event->mimeData()->hasFormat(appletMimeType)) {
+    if (isContainment()) {
         Containment::dropEvent(event);
     }
 }
@@ -1383,12 +1304,26 @@ void FolderView::dropEvent(QGraphicsSceneDragDropEvent *event)
 void FolderView::setUrl(const KUrl &url)
 {
     m_url = url;
-
     setAssociatedApplicationUrls(KUrl::List() << m_url);
 
+    if (KProtocolInfo::protocolClass(m_url.protocol()) == ":local") {
+        disconnect(Solid::Networking::notifier(), 0, this, 0);
+        m_dirLister->openUrl(m_url);
+    } else {
+        //If host is connected to the network and url is remote, list the remote files
+        connect(Solid::Networking::notifier(), SIGNAL(shouldConnect()), this,
+                SLOT(networkAvailable()), Qt::UniqueConnection);
+        //Check if network is not in the "Connected" state
+        if (Solid::Networking::status() == Solid::Networking::Connected) {
+             //FIXME: Remove the comment when KDE 4.9 development starts
+            //QString networkStatus(i18n("Network is not reachable"));
+            //showMessage(KIcon("dialog-warning"), networkStatus, Plasma::ButtonOk);
+            m_dirLister->openUrl(m_url);
+        }
+    }
+
     // Only parse desktop files when sorting if we're showing the desktop folder
     m_model->setParseDesktopFiles(m_url.protocol() == "desktop");
-
     setAppletTitle();
 }
 
@@ -1512,8 +1447,8 @@ void FolderView::createActions()
     KAction *trash = new KAction(KIcon("user-trash"), i18n("&Move to Trash"), this);
     trash->setShortcut(Qt::Key_Delete);
     trash->setShortcutContext(Qt::WidgetShortcut);
-    connect(trash, SIGNAL(triggered(Qt::MouseButtons, Qt::KeyboardModifiers)),
-            SLOT(moveToTrash(Qt::MouseButtons, Qt::KeyboardModifiers)));
+    connect(trash, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)),
+            SLOT(moveToTrash(Qt::MouseButtons,Qt::KeyboardModifiers)));
 
     KAction *emptyTrash = new KAction(KIcon("trash-empty"), i18n("&Empty Trash Bin"), this);
     KConfig trashConfig("trashrc", KConfig::SimpleConfig);
@@ -1594,7 +1529,7 @@ void FolderView::createActions()
         // Create the new menu
         m_newMenu = new KNewFileMenu(&m_actionCollection, "new_menu", QApplication::desktop());
         m_newMenu->setModal(false);
-        
+
         connect(m_newMenu->menu(), SIGNAL(aboutToShow()), this, SLOT(aboutToShowCreateNew()));
 
         m_actionCollection.addAction("lock_icons", lockIcons);
@@ -1609,6 +1544,20 @@ void FolderView::createActions()
     }
 }
 
+void FolderView::updatePasteAction()
+{
+    if (QAction *paste = m_actionCollection.action("paste")) {
+        const QString pasteText = KIO::pasteActionText();
+        if (pasteText.isEmpty()) {
+            paste->setText(i18n("&Paste"));
+            paste->setEnabled(false);
+        } else {
+            paste->setText(pasteText);
+            paste->setEnabled(true);
+        }
+    }
+}
+
 QList<QAction*> FolderView::contextualActions()
 {
     QList<QAction*> actions;
@@ -1624,7 +1573,10 @@ QList<QAction*> FolderView::contextualActions()
         }
 
         actions.append(m_actionCollection.action("undo"));
-        actions.append(m_actionCollection.action("paste"));
+        if (QAction *paste = m_actionCollection.action("paste")) {
+            updatePasteAction();
+            actions.append(paste);
+        }
 
         QAction *separator = new QAction(this);
         separator->setSeparator(true);
@@ -1651,6 +1603,9 @@ QList<QAction*> FolderView::contextualActions()
         }
         actions.append(m_itemActions->preferredOpenWithAction(QString()));
         if (m_url.protocol() == "trash") {
+            KConfig trashConfig("trashrc", KConfig::SimpleConfig);
+            m_actionCollection.action("empty_trash")->setEnabled(!trashConfig.group("Status")
+                                      .readEntry("Empty", true));
             actions.append(m_actionCollection.action("empty_trash"));
         }
 
@@ -1748,6 +1703,20 @@ void FolderView::toggleAlignToGrid(bool align)
     m_delayedSaveTimer.start(5000, this);
 }
 
+void FolderView::toggleClickToViewFolders(bool enable)
+{
+   m_clickToView = enable;
+  
+    if (m_iconView) {
+        m_iconView->setClickToViewFolders(enable);
+    }
+
+    config().writeEntry("clickForFolderPreviews", enable);
+    emit configNeedsSaving();
+
+    m_delayedSaveTimer.start(5000, this);
+}
+
 void FolderView::toggleDirectoriesFirst(bool enable)
 {
     m_sortDirsFirst = enable;
@@ -1912,8 +1881,11 @@ void FolderView::showContextMenu(QWidget *widget, const QPoint &pos, const QMode
 
     QAction* pasteTo = m_actionCollection.action("pasteto");
     if (pasteTo) {
-        pasteTo->setEnabled(m_actionCollection.action("paste")->isEnabled());
-        pasteTo->setText(m_actionCollection.action("paste")->text());
+        if (QAction *paste = m_actionCollection.action("paste")) {
+            updatePasteAction();
+            pasteTo->setEnabled(paste->isEnabled());
+            pasteTo->setText(paste->text());
+        }
     }
 
     QList<QAction*> editActions;
